@@ -10,5 +10,5 @@ class Provider(PhoneNumberProvider):
         '+39 ### #######',
         '+39 ### ########',
         '+39 #### #######',
-        '+39 #### ########'
-    )
\ No newline at end of file
+        '+39 #### ########',
+    )
